<?php

/**
  * SquirrelMail Debugger
  * Copyright (C) 2004-2005 Paul Lesneiwski <pdontthink@angrynerds.com>
  * This program is licensed under BSD (because some portions of
  * the source are already licensed under BSD; typical SquirrelMail
  * license is GPL). See COPYING for details
  *
  */



/** @ignore */
if (!defined('SM_PATH'))
   define('SM_PATH', '../../');



if (file_exists(SM_PATH . 'include/validate.php'))
   include_once(SM_PATH . 'include/validate.php');
else
   include_once(SM_PATH . 'src/validate.php');



// get global variable for versions of PHP < 4.1
//
if (!check_php_version(4,1)) {
   global $HTTP_SESSION_VARS;
   $_SESSION = $HTTP_SESSION_VARS;
}



sqgetGlobalVar('myget', $myget, SQ_FORM);
sqgetGlobalVar('mypost', $mypost, SQ_FORM);
sqgetGlobalVar('myserver', $myserver, SQ_FORM);



bindtextdomain ('debugger', SM_PATH . 'locale');
textdomain ('debugger');



echo '<html><head><title>' ._("SquirrelMail Debugger") 
   . '</title></head><body><br />'
   . '<strong>GET:</strong><br />'
   . $myget . '<br />'
   . '<strong>POST:</strong><br />'
   . $mypost . '<br />'
   . '<strong>SESSION:</strong><br />';

sm_print_r($_SESSION);

echo '<br /><strong>SERVER:</strong><br />'
   . $myserver . '<br />';



bindtextdomain ('squirrelmail', SM_PATH . 'locale');
textdomain ('squirrelmail');



?>
</body>
</html>
